@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Calculate date-time operations
 
-our $VERSION = '0.03';
+our $VERSION = '0.0301';
 
 use strict;
 use warnings;
@@ -21,7 +21,7 @@ sub help {
 
     $self->say(
         channel => $arguments->{channel},
-        body    => 'source|now|localtime $stamp|dow $stamp|diff $stamp $stamp|{add,sub}_{years,months,days,hours,minutes,seconds} $offset $stamp',
+        body    => 'source|now|localtime $epoch|dow $stamp|diff $stamp $stamp|{add,sub}_{years,months,days,hours,minutes,seconds} $offset $stamp',
     );
 }
 
@@ -84,7 +84,7 @@ sub said {
         }
         # Exit IRC
         elsif ( $arguments->{body} =~ /^leave$/ ) {
-            $self->shutdown('I have done my job here.');
+            $self->shutdown( $self->quit_message() );
             exit;
         }
 
@@ -124,7 +124,7 @@ Bot::BasicBot::Pluggable::Module::DateTimeCalc - Calculate date-time operations
 
 =head1 VERSION
 
-version 0.03
+version 0.0301
 
 =head1 SYNOPSIS
 
